@@ -2,10 +2,20 @@ package Net::DNS::SEC;
 
 use strict;
 use warnings;
+use Carp;
 
+our $SVNVERSION = (qw$Id: SEC.pm 1869 2022-08-31 20:15:05Z willem $)[2];
 our $VERSION;
-$VERSION = '1.17_01';
-our $SVNVERSION = (qw$Id: SEC.pm 1807 2020-09-28 11:38:28Z willem $)[2];
+$VERSION = '1.19_01';
+
+use base qw(Exporter DynaLoader);
+
+eval { __PACKAGE__->bootstrap($VERSION) };
+warn "\n\n$@\n" if $@;
+
+use Net::DNS 1.01 qw(:DEFAULT);
+
+our @EXPORT = ( @Net::DNS::EXPORT, qw(algorithm digtype key_difference) );
 
 
 =head1 NAME
@@ -33,16 +43,6 @@ Net::DNS::SEC in the use declaration.
 =cut
 
 
-use base qw(Exporter DynaLoader);
-
-use Net::DNS 1.01 qw(:DEFAULT);
-
-our @EXPORT = ( @Net::DNS::EXPORT, qw(algorithm digtype key_difference) );
-
-use integer;
-use Carp;
-
-
 =head1 UTILITY FUNCTIONS
 
 =head2 algorithm
@@ -86,41 +86,30 @@ Fills @result with all keys in array @a that are not in array @b.
 sub key_difference {
 	my $a = shift;
 	my $b = shift;
-	my $r = shift || [];		## 0.17 interface
+	my $r = shift || [];		## 0.17 API
 
-	eval {
-		local $SIG{__DIE__};
-		my ($x) = grep { !$_->isa('Net::DNS::RR::DNSKEY') } @$a, @$b;
-		die sprintf 'unexpected %s object in key list', ref($x) if $x;
+	local $SIG{__DIE__};
+	my ($x) = grep { !$_->isa('Net::DNS::RR::DNSKEY') } @$a, @$b;
+	croak sprintf( 'unexpected %s object in key list', ref $x ) if $x;
 
-		my %index = map { ( $_->privatekeyname => 1 ) } @$b;
-		@$r = grep { !$index{$_->privatekeyname} } @$a;
-		1;
-	} || do {
-		croak($@) if wantarray;
-	};
-
-	return wantarray ? (@$r) : $@;
+	my %index = map { ( $_->privatekeyname => 1 ) } @$b;
+	return @$r = grep { !$index{$_->privatekeyname} } @$a;
 }
 
 
 ########################################
 
-eval { Net::DNS::SEC->bootstrap($VERSION) } || croak;
-
-
 foreach (qw(DS CDS RRSIG)) {
 	Net::DNS::RR->new( type => $_ );			# pre-load to access class methods
 }
 
-
 1;
 __END__
 
 
 =head1 COPYRIGHT
 
-Copyright (c)2014-2018 Dick Franks
+Copyright (c)2014-2021 Dick Franks
 
 Copyright (c)2001-2005 RIPE NCC. Author Olaf M. Kolkman
 
@@ -131,7 +120,7 @@ All Rights Reserved
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
